@@ -1,5 +1,7 @@
 import importlib
 import logging
+import os
+import sys
 import click
 
 import soin
@@ -14,15 +16,15 @@ def cli():
 @cli.command()
 @click.argument("module")
 @click.option("-w", "--worker", is_flag=True, default=False, help="spawn as worker")
-def start(module, worker):
+@click.option("-s", "--steps", default=None, help="max step for a worker to run")
+def start(module, worker, steps=None):
+    sys.path.insert(0, os.getcwd())
     module = importlib.import_module(module)
     spider : soin.Spider = module.Main()
-    spider.setup()
     if worker:
-        spider.as_worker()
+        spider.as_worker(steps)
     else:
-        spider.spawn_worker_thread()
-        spider.run()
+        spider.main()
     logging.info("Gracefully existed!")
 
 
